@@ -18,18 +18,15 @@
 Command-line interface to the OpenStack Nova API.
 """
 
-from __future__ import print_function
 import argparse
 import logging
+import os
 import sys
 
 from keystoneauth1 import loading
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import strutils
-import six
-
-osprofiler_profiler = importutils.try_import("osprofiler.profiler")
 
 import novaclient
 from novaclient import api_versions
@@ -39,6 +36,8 @@ import novaclient.extension
 from novaclient.i18n import _
 from novaclient import utils
 
+osprofiler_profiler = importutils.try_import("osprofiler.profiler")
+
 DEFAULT_MAJOR_OS_COMPUTE_API_VERSION = "2.0"
 # The default behaviour of nova client CLI is that CLI negotiates with server
 # to find out the most recent version between client and server, and
@@ -123,7 +122,7 @@ class DeprecatedAction(argparse.Action):
             # option
             self.real_action_args = False
             self.real_action = None
-        elif real_action is None or isinstance(real_action, six.string_types):
+        elif real_action is None or isinstance(real_action, str):
             # Specified by string (or None); we have to have a parser
             # to look up the actual action, so defer to later
             self.real_action_args = (option_strings, dest, help, kwargs)
@@ -367,25 +366,8 @@ class OpenStackComputeShell(object):
             help=_("Use this API endpoint instead of the Service Catalog. "
                    "Defaults to env[OS_ENDPOINT_OVERRIDE]."))
 
-        # NOTE(takashin): This dummy '--end' argument was added
-        # to avoid misinterpreting command line arguments.
-        # If there is not this dummy argument, the '--end' is interpreted to
-        # the '--endpoint-override'.
-        # TODO(takashin): Remove this dummy '--end' argument
-        # when the deprecated '--endpoint-override' argument is removed.
-        parser.add_argument(
-            '--end',
-            metavar='<end>',
-            nargs='?',
-            help=argparse.SUPPRESS)
-
-        parser.add_argument(
-            '--endpoint-override',
-            action=DeprecatedAction,
-            use=_('use "%s"; this option will be removed after Rocky '
-                  'OpenStack release.') % '--os-endpoint-override',
-            dest='endpoint_override',
-            help=argparse.SUPPRESS)
+        parser.set_defaults(func=self.do_help)
+        parser.set_defaults(command='')
 
         if osprofiler_profiler:
             parser.add_argument('--profile',
@@ -463,6 +445,7 @@ class OpenStackComputeShell(object):
 
             action_help = desc.strip()
             arguments = getattr(callback, 'arguments', [])
+            groups = {}
 
             subparser = subparsers.add_parser(
                 command,
@@ -477,10 +460,14 @@ class OpenStackComputeShell(object):
             )
             self.subcommands[command] = subparser
             for (args, kwargs) in arguments:
-                start_version = kwargs.get("start_version", None)
+                kwargs = kwargs.copy()
+
+                start_version = kwargs.pop("start_version", None)
+                end_version = kwargs.pop("end_version", None)
+                group = kwargs.pop("group", None)
+
                 if start_version:
                     start_version = api_versions.APIVersion(start_version)
-                    end_version = kwargs.get("end_version", None)
                     if end_version:
                         end_version = api_versions.APIVersion(end_version)
                     else:
@@ -492,10 +479,16 @@ class OpenStackComputeShell(object):
                             "end": end_version.get_string()})
                     if not version.matches(start_version, end_version):
                         continue
-                kw = kwargs.copy()
-                kw.pop("start_version", None)
-                kw.pop("end_version", None)
-                subparser.add_argument(*args, **kw)
+
+                if group:
+                    if group not in groups:
+                        groups[group] = (
+                            subparser.add_mutually_exclusive_group()
+                        )
+                    kwargs['dest'] = kwargs.get('dest', group)
+                    groups[group].add_argument(*args, **kwargs)
+                else:
+                    subparser.add_argument(*args, **kwargs)
             subparser.set_defaults(func=callback)
 
     def setup_debugging(self, debug):
@@ -824,16 +817,23 @@ class OpenStackHelpFormatter(argparse.HelpFormatter):
         super(OpenStackHelpFormatter, self).start_section(heading)
 
 
-def main():
+def main(argv=sys.argv[1:]):
     try:
-        argv = [encodeutils.safe_decode(a) for a in sys.argv[1:]]
+        # Special dansmith envvar to hide the warning. Don't rely on this
+        # because we will eventually remove all this stuff.
+        if os.environ.get("NOVACLIENT_ISHOULDNTBEDOINGTHIS") != "1":
+            print(
+                _(
+                    "nova CLI is deprecated and will be a removed in a future "
+                    "release"
+                ),
+                file=sys.stderr,
+            )
+        argv = [encodeutils.safe_decode(a) for a in argv]
         OpenStackComputeShell().main(argv)
     except Exception as exc:
         logger.debug(exc, exc_info=1)
-        if six.PY2:
-            message = encodeutils.safe_encode(six.text_type(exc))
-        else:
-            message = encodeutils.exception_to_unicode(exc)
+        message = encodeutils.exception_to_unicode(exc)
         print("ERROR (%(type)s): %(msg)s" % {
               'type': exc.__class__.__name__,
               'msg': message},
